Public Codeforces problem metadata
Structs
- ApiCredentials
- Credentials generated at Codeforces’ API settings page
- Client
- Contest
- A public Codeforces contest, suitable for calendars and status views
- Discussion
- A public Codeforces blog entry and its public comments
- Discussion
Comment - Metadata and text for one public Codeforces blog comment
- Discussion
Preview - A public Codeforces blog entry surfaced by the recent activity feed
- Problem
- Rating
Change - One change in a user’s Codeforces rating history
- Submission
- A public submission returned by
user.status - User
Profile - Public account information returned by
user.info